



{% extends "base.html" %}







{% block contents %}




<div class="section">

    <div class='sectionheader'> <h2>{{current_filegroup.name}}</h2> </div>


{% for simfile in simfiles %}

    <div class="subsection">
        <h3> <a href="/simfiles/{{simfile.id}}">{{simfile.get_short_filename}}</a> </h3>



        {% if simfile.get_last_run %}


            {% if simfile.get_docstring %}
            <div class="SummaryFileDescription">
                <pre> {{simfile.get_docstring}} </pre>
            </div>
            {% else %}
            <div>(No Docstring)</div>
            {% endif %}
            {% if not simfile.is_queued %}
                {% for i in simfile.get_last_run.output_images.all %}
                <a href="/image/{{i.hash_name_short}}">
                    <img src="/image/{{i.hash_thumbnailname_short}}"/>
 1               </a>
                {% endfor %}
            {% else %}
             (Currently Queued to Run)
            {% endif %}
        {% else %}
        [Never been run]: 
        {% endif %}
    </div>
{% endfor %}
  </div>

{% endblock  %}







