{% load dajaxice_templatetags %}

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
  <title>mreorg.curate</title>
  <meta http-equiv="Content-Language" content="English" />
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  <link rel="stylesheet" href="{{ STATIC_URL }}customcss/haiku_mod.css"  type="text/css"  />
  <script src="{{ STATIC_URL }}javascript/prototype.js" type="text/javascript"></script>
  <script src="{{ STATIC_URL }}javascript/scriptaculous.js" type="text/javascript"></script>
  <script src="{{ STATIC_URL }}javascript-moment/moment.js" type="text/javascript"></script>

  <!-- Dajax -->s
  {% dajaxice_js_import %}

  <!-- Template overridable block -->
  {% block additional_header %} 
  {% endblock %}



<script>
function myreloadfunction(data)
{
    window.location.reload()
}
</script>


</head>




<body>

<div id="banner">
  <div><span>MREORG:curate</span></div>
</div>

<!-- The top menu -->
<div class='nav'>
  <div class='outer'>
      <div class='inner'>
         <ul>
            <li> <a href="/overview"><span>Overview<span></span></a></li>
            <li> <a href="/viewsimulationoutputsummaries"><span>Output<span></span></a></li>
            <li> <a href="/tracking"><span>Tracking</span></a></li>
            <li> <a href="/viewsimulationqueue"><span>Queue</span></a></li>
            <li> <a href="/viewsimulationfailures"><span>Failures</span></a></li>
            <li> <a href="" onclick="Effect.toggle('config', 'blind',{ duration: 0.3 }); return false;"><span>Config</span></a></li>
        </ul>
      </div>

      <div class='inner'>
          <div id='config'> <!-- style="display: none"> -->
            <ul>
            <li>
                    <form action="switch_config" method="POST" >
                    <span>
                        Config:
                            <select name="configuration" onchange="Dajaxice.mreorg.curator.frontend.base_set_runconfig(myreloadfunction, {'runconfig_id':this.options[this.selectedIndex].value}); ">  
                                <option value={{current_runconfig.id}}>{{current_runconfig.name}}</option> 
                            {% for config in runconfigs %} 
                            {% if config.id != current_runconfig.id%}
                                <option value={{config.id}}>{{config.name}}</option> 
                            {% endif %}
                            {% endfor %}
                        </select>
                    </span>

                </form>
            </li>
            <li>
                <form action="switch_filegroup" method="POST">
                    <span>Group <select name="group1" onchange="Dajaxice.mreorg.curator.frontend.base_set_filegroup(myreloadfunction, {'filegroup_id':this.options[this.selectedIndex].value}); "> 
                            <option value={{current_filegroup.id}}>{{current_filegroup.display_name}}</option> 
                            {% for filegroup in filegroups %} 
                            {% if filegroup.id != current_filegroup.id%}
                            <option value={{filegroup.id}}>{{filegroup.name}}</option> 
                            {% endif %}
                            {% endfor %}
                    </select> </span>
                </form>
            </li>
            <li> <a href='/viewconfigurations'><span>More...</span></a> </li>
            <ul>
    </div >
    </div >

  </div>
</div >

<!-- the main content block -->
<div id='content'>

  {% block contents %} 
  {% endblock %}

</div>


</body>

{% block postbody %}
{% endblock %}

</html>


