/*
 * Copyright 2008-2009, Haiku. All rights reserved.
 * Distributed under the terms of the MIT License.
 *
 * Authors:
 *    FranÃ§ois Revol <revol@free.fr>
 *    Stephan AÃŸmus <superstippi@gmx.de>
 *    Braden Ewing <brewin@gmail.com>
 *    Humdinger <humdingerb@gmail.com>
 */


/*
 * Copyright 2008-2009, Haiku. All rights reserved.
 * Distributed under the terms of the MIT License.
 *
 * Authors:
 *		FranÃ§ois Revol <revol@free.fr>
 *		Stephan AÃŸmus <superstippi@gmx.de>
 *		Braden Ewing <brewin@gmail.com>
 *		Humdinger <humdingerb@gmail.com>
 *		Vincent Duvert <vincent.duvert@free.fr>
 */

html {
	margin: 0;
	padding: 0;
	background: #FFF;
}

body {
	color: #333333;
	line-height: 1.5;
	margin: 0;
	padding: 0;
	font-family: "DejaVu Sans", Arial, Helvetica, sans-serif;
}

/* link colors and text decoration */

a:link { 
	font-weight: bold; 
	text-decoration: none; 
	color: #dc3c01;
}
a:visited { 
	font-weight: bold; 
	text-decoration: none; 
	color: #892601;
}
a:hover, a:active { 
	text-decoration: underline; 
	color: #ff4500;
}

/* Some headers act as anchors, don't give them a hover effect */

h2 a:hover, a:active {
	text-decoration: none;
	color: #0c3762;
}
h3 a:hover, a:active {
	text-decoration: none;
	color: #0c3762;
}
h4 a:hover, a:active {
	text-decoration: none;
	color: #0c3762;
}
h5 a:hover, a:active {
	text-decoration: none;
	color: #0c3762;
}

/* heading and navigation */

#banner {
	position: relative;
	left: 0;
	top: 0;
	height: 84px;
	background: #eeeeee;
}

#banner div {
	background: transparent; /*url(images/logo.png) no-repeat scroll 10px 0;*/
	height: 100%;
	margin: 0 auto;
  width:80%;
}

#banner span {
	position: relative;
	top: 26px;
	color: #333333;
	text-transform: uppercase;
	letter-spacing: 3px;
	font-family: Myriad Pro,Myriad Web Pro Regular,Lucida Grande,Geneva,Trebuchet MS,sans-serif;
	font-weight: normal;
	font-size: 28px;	
  width:95%;
}



div.nav {
	background: #e0e0e0;
	padding: 0;
    margin-bottom:30px;
	height: 26px;
}


#div.config {
}

div.nav div.outer {
  width:95%;
  float:left;
}
div.nav div.outer div.inner {
	height: 100%;
	text-align: right;
	padding: 0;
  float:right;
  clear: right;
}

div.nav div.inner span {
	margin-right: 5px;
	font-size: 0.9em;
}



div.nav div.inner ul
{
list-style-type:none;
margin:0;
padding:0;
}
div.nav div.inner ul span
{
display:block;
width:auto;
margin:5px;
/*margin-left:5px;*/
font-variant:small-caps;
}
div.nav div.inner ul li
{
display:inline;
float: left; 
}













/* main content */
#content {
	margin: 0 auto;
  width:80%;
}



#content div {
	font-size: 0.9em;
}

/* contents box */

table.std {
	margin: 0px 0px 30px 30px;
	padding: 1px;
	border-width: 1px;
	border-style: dotted;
	border-color: #e0e0e0;
	float:center;
  margin:auto;
}

/*
table.std tr.heading {
	background-color: #e0e0e0;
	text-align: center;
	font-weight: bold;
	font-size: 1.1em;
}
*/


/*
table.std tr.std {
	background-color: #eeeeee;
}
*/
table.std td {
	padding: 5px 20px;
  /*text-align:center; */

	font-size: 0.80em;
}

table.std a:link, table.std a:visited { 
	font-weight: normal; 
	text-decoration: none; 
	color: #dc3c01;
}
table.std a:hover, table.std a:active { 
	text-decoration: underline; 
	color: #ff4500;
}


/* More layout and styles */
h1 {
	font-size: 1.3em;
	font-weight: bold;
	color: #0c3762;
  /*
	border-bottom: dotted thin #e0e0e0;
	margin-bottom: 25px;
  */
}
h2 {
	font-size: 1.3em;
	font-weight: normal;
	color: #0c3762;
  /*
	border-bottom: dotted thin #e0e0e0;
	margin-top: 35px;
  */
}
h3 {
	font-size: 1.2em;
	font-weight: normal;
	color: #0c3762;
	border-bottom: dotted thin #e0e0e0;
	margin-top: 30px;
}
h4 {
	font-size: 1.1em;
	font-weight: normal;
	color: #0c3762;
	margin-top: 30px;
}
h5 {
	font-size: 1.0em;
	font-weight: normal;
	color: #0c3762;
	margin-top: 30px;
}

p {
	text-align: justify;
}



pre {
	border-color: #0c3762;
	border-style: dotted;
	border-width: thin;
	margin: 0em;
	padding: 1.5em;
	background-color: #f0f0f0;
}






#content div.content div.section div.sectionheader h2
{
  padding-bottom:0px;
  margin-bottom:0px;
}

#content div.section
{
margin-bottom:30px;
}

#content div.subsection
{
margin-bottom:30px;
width:95%;
float:right;
}


div.sectionheader
{
	border-bottom: thin dotted #e0e0e0;
	margin-top: 45px;
	margin-bottom: 35px;
}
div.sectionheader div h2 a 
{
  padding:0;
  margin:0;
}
/*#content div.content div.section div.sectionheader */
div.actionbar
{
  margin-top:0px;
  padding:0px;
  float:right;
}



div.actionbar div.inner ul li 
{
display:inline;
float: left;
}
div.actionbar div.inner ul li span
{
display:block;
width:auto;
margin-right:5px;
margin-left:5px;
}

div.sectioncontents
{
  clear:both;
}


div.section
{
  clear:both;
}













.Success { background-color: #AAFFAA; }
.FileChanged {background-color: #FFCC99; }
.UnhandledException { background-color: #ffcfcf }
.UnhandledException td.Status{ background-color: #ffcfcf }
.TimeOut { background-color: #99CCCC }
.NeverBeenRun { background-color: #FFFFCC }
.Unknown {}

.SimQueued td.Toggle {
  	border-top: 3px solid #aaaaaa;
  	border-bottom: 3px solid #aaaaaa;
    margin: 0px;
    /*padding: 0px;*/
    text-align:center;
	  padding: 5px 20px;
}



div.centerform
{
  float:center;
  margin:auto;
  text-align:center;

}

